@@ -17,8 +17,8 @@
 #define _TK
 
 #include <tcl.h>
-#if (TCL_MAJOR_VERSION < 9) && defined(TCL_MINOR_VERSION) && (TCL_MINOR_VERSION < 7)
-#	error Tk 9.0 must be compiled with tcl.h from Tcl 8.7 or better
+#if (TCL_MAJOR_VERSION < 9)
+#	error Tk 9.0 must be compiled with tcl.h from Tcl 9.0 or better
 #endif
 
 #ifndef EXTERN
@@ -55,7 +55,6 @@ extern "C" {
  * unix/configure.ac	(2 LOC Major, 2 LOC minor, 1 LOC patch)
  * win/configure.ac	(as above)
  * README.md		(sections 0 and 1)
- * macosx/Tk-Common.xcconfig (not patchlevel) 1 LOC
  * win/README		(not patchlevel)
  * unix/README		(not patchlevel)
  * unix/tk.spec		(1 LOC patch)
@@ -71,10 +70,10 @@ extern "C" {
 #if TK_MAJOR_VERSION == 9
 #   define TK_MINOR_VERSION	0
 #   define TK_RELEASE_LEVEL	TCL_FINAL_RELEASE
-#   define TK_RELEASE_SERIAL	0
+#   define TK_RELEASE_SERIAL	3
 
 #   define TK_VERSION		"9.0"
-#   define TK_PATCH_LEVEL		"9.0.0"
+#   define TK_PATCH_LEVEL		"9.0.3"
 #endif /* TK_MAJOR_VERSION */
 
 /*
@@ -564,6 +563,7 @@ typedef struct Tk_FontMetrics {
 #define TK_WHOLE_WORDS		1
 #define TK_AT_LEAST_ONE		2
 #define TK_PARTIAL_OK		4
+#define TK_ISOLATE_END		32
 
 /*
  * Flags passed to Tk_ComputeTextLayout:
@@ -729,9 +729,9 @@ typedef XActivateDeactivateEvent XDeactivateEvent;
 #define Tk_Depth(tkwin)		(((Tk_FakeWin *) (tkwin))->depth)
 #define Tk_Visual(tkwin)	(((Tk_FakeWin *) (tkwin))->visual)
 #define Tk_WindowId(tkwin)	(((Tk_FakeWin *) (tkwin))->window)
-#define Tk_PathName(tkwin) 	(((Tk_FakeWin *) (tkwin))->pathName)
+#define Tk_PathName(tkwin)	(((Tk_FakeWin *) (tkwin))->pathName)
 #define Tk_Name(tkwin)		(((Tk_FakeWin *) (tkwin))->nameUid)
-#define Tk_Class(tkwin) 	(((Tk_FakeWin *) (tkwin))->classUid)
+#define Tk_Class(tkwin)	(((Tk_FakeWin *) (tkwin))->classUid)
 #define Tk_X(tkwin)		(((Tk_FakeWin *) (tkwin))->changes.x)
 #define Tk_Y(tkwin)		(((Tk_FakeWin *) (tkwin))->changes.y)
 #define Tk_Width(tkwin)		(((Tk_FakeWin *) (tkwin))->changes.width)
@@ -996,7 +996,7 @@ typedef struct Tk_Item {
  *
  * TK_ITEM_STATE_DEPENDANT -	1 means that object needs to be redrawn if the
  *				canvas state changes.
- * TK_ITEM_DONT_REDRAW - 	1 means that the object redraw is already been
+ * TK_ITEM_DONT_REDRAW -	1 means that the object redraw is already been
  *				prepared, so the general canvas code doesn't
  *				need to do that any more.
  */
@@ -1155,9 +1155,11 @@ typedef struct Tk_CanvasTextInfo {
     int cursorOn;		/* Non-zero means that an insertion cursor
 				 * should be displayed in focusItemPtr.
 				 * Read-only to items.*/
+#if TK_MAJOR_VERSION > 8
     void *reserved1;		/* reserved for future use */
     void *reserved2;
     void *reserved3;
+#endif
 } Tk_CanvasTextInfo;
 
 /*
@@ -1336,7 +1338,7 @@ typedef int (Tk_ImageStringWriteProc) (Tcl_Interp *interp, Tcl_Obj *format,
 	Tk_PhotoImageBlock *blockPtr);
 
 /*
- * The following alternate definitions are used with the Tk8.7 file format
+ * The following alternate definitions are used with the Tk9.0 file format
  * supporting a metadata dict, internal dstring and close file flag
  */
 
@@ -1553,7 +1555,7 @@ typedef Tcl_Size (Tk_SelectionProc) (void *clientData, Tcl_Size offset,
  *----------------------------------------------------------------------
  */
 
-#include "tkDecls.h"
+#include "tkDecls.h"  /* IWYU pragma: export */
 
 #undef TCL_STORAGE_CLASS
 #define TCL_STORAGE_CLASS DLLIMPORT
