@@ -3,7 +3,7 @@
  *
  *	Declarations of types and functions shared by the 3d border module.
  *
- * Copyright (c) 1996-1997 Sun Microsystems, Inc.
+ * Copyright © 1996-1997 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -28,7 +28,7 @@ typedef struct TkBorder {
 				 * the border will be used. */
     Colormap colormap;		/* Colormap out of which pixels are
 				 * allocated. */
-    int resourceRefCount;	/* Number of active uses of this color (each
+    Tcl_Size resourceRefCount;	/* Number of active uses of this color (each
 				 * active use corresponds to a call to
 				 * Tk_Alloc3DBorderFromObj or Tk_Get3DBorder).
 				 * If this count is 0, then this structure is
@@ -37,7 +37,7 @@ typedef struct TkBorder {
 				 * because there are objects referring to it.
 				 * The structure is freed when objRefCount and
 				 * resourceRefCount are both 0. */
-    int objRefCount;		/* The number of Tcl objects that reference
+    Tcl_Size objRefCount;		/* The number of Tcl objects that reference
 				 * this structure. */
     XColor *bgColorPtr;		/* Background color (intensity between
 				 * lightColorPtr and darkColorPtr). */
