@@ -537,7 +537,7 @@ TkCreateFrame(
 
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		"unable to create widget \"%s\"", Tcl_GetString(objv[1])));
-	Tcl_SetErrorCode(interp, "TK", "APPLICATION_GONE", NULL);
+	Tcl_SetErrorCode(interp, "TK", "APPLICATION_GONE", (char *)NULL);
 	return TCL_ERROR;
     } else {
 	/*
@@ -657,7 +657,7 @@ TkCreateFrame(
 	    Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		    "windows cannot have both the -use and the -container"
 		    " option set", TCL_INDEX_NONE));
-	    Tcl_SetErrorCode(interp, "TK", "FRAME", "CONTAINMENT", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "FRAME", "CONTAINMENT", (char *)NULL);
 	    goto error;
 	}
 	Tk_MakeContainer(framePtr->tkwin);
@@ -1083,7 +1083,7 @@ ConfigureFrame(
     Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 	    "can't use %s as label in this frame",
 	    Tk_PathName(labelframePtr->labelWin)));
-    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "HIERARCHY", NULL);
+    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "HIERARCHY", (char *)NULL);
     labelframePtr->labelWin = NULL;
     return TCL_ERROR;
 }
