@@ -233,7 +233,7 @@ Tk_PackObjCmd(
 	if (argv2[0] != '.') {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "bad argument \"%s\": must be name of window", argv2));
-	    Tcl_SetErrorCode(interp, "TK", "VALUE", "WINDOW_PATH", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "VALUE", "WINDOW_PATH", (char *)NULL);
 	    return TCL_ERROR;
 	}
 	return ConfigureContent(interp, tkwin, objc-2, objv+2);
@@ -279,7 +279,7 @@ Tk_PackObjCmd(
 	if (contentPtr->containerPtr == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "window \"%s\" isn't packed", argv2));
-	    Tcl_SetErrorCode(interp, "TK", "PACK", "NOT_PACKED", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "PACK", "NOT_PACKED", (char *)NULL);
 	    return TCL_ERROR;
 	}
 
@@ -1252,7 +1252,7 @@ ConfigureContent(
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "can't pack \"%s\": it's a top-level window",
 		    Tcl_GetString(objv[j])));
-	    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "TOPLEVEL", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "TOPLEVEL", (char *)NULL);
 	    return TCL_ERROR;
 	}
 	if (!(contentPtr = GetPacker(content))) {
@@ -1281,7 +1281,7 @@ ConfigureContent(
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			"extra option \"%s\" (option with no value?)",
 			Tcl_GetString(objv[i])));
-		Tcl_SetErrorCode(interp, "TK", "PACK", "BAD_PARAMETER", NULL);
+		Tcl_SetErrorCode(interp, "TK", "PACK", "BAD_PARAMETER", (char *)NULL);
 		return TCL_ERROR;
 	    }
 	    if (Tcl_GetIndexFromObj(interp, objv[i], optionStrings,
@@ -1365,7 +1365,7 @@ ConfigureContent(
 		    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			    "bad fill style \"%s\": must be "
 			    "none, x, y, or both", string));
-		    Tcl_SetErrorCode(interp, "TK", "VALUE", "FILL", NULL);
+		    Tcl_SetErrorCode(interp, "TK", "VALUE", "FILL", (char *)NULL);
 		    return TCL_ERROR;
 		}
 		break;
@@ -1393,7 +1393,7 @@ ConfigureContent(
 		    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			    "bad ipadx value \"%s\": must be positive screen"
 			    " distance", Tcl_GetString(objv[i+1])));
-		    Tcl_SetErrorCode(interp, "TK", "VALUE", "INT_PAD", NULL);
+		    Tcl_SetErrorCode(interp, "TK", "VALUE", "INT_PAD", (char *)NULL);
 		    return TCL_ERROR;
 		}
 		contentPtr->iPadX = tmp * 2;
@@ -1404,7 +1404,7 @@ ConfigureContent(
 		    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			    "bad ipady value \"%s\": must be positive screen"
 			    " distance", Tcl_GetString(objv[i+1])));
-		    Tcl_SetErrorCode(interp, "TK", "VALUE", "INT_PAD", NULL);
+		    Tcl_SetErrorCode(interp, "TK", "VALUE", "INT_PAD", (char *)NULL);
 		    return TCL_ERROR;
 		}
 		contentPtr->iPadY = tmp * 2;
@@ -1486,14 +1486,14 @@ ConfigureContent(
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			"can't pack \"%s\" inside \"%s\"", Tcl_GetString(objv[j]),
 			Tk_PathName(containerPtr->tkwin)));
-		Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "HIERARCHY", NULL);
+		Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "HIERARCHY", (char *)NULL);
 		return TCL_ERROR;
 	    }
 	}
 	if (content == containerPtr->tkwin) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "can't pack \"%s\" inside itself", Tcl_GetString(objv[j])));
-	    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "SELF", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "SELF", (char *)NULL);
 	    return TCL_ERROR;
 	}
 
@@ -1507,7 +1507,7 @@ ConfigureContent(
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			"can't put \"%s\" inside \"%s\": would cause management loop",
 			Tcl_GetString(objv[j]), Tk_PathName(containerPtr->tkwin)));
-		Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "LOOP", NULL);
+		Tcl_SetErrorCode(interp, "TK", "GEOMETRY", "LOOP", (char *)NULL);
 		return TCL_ERROR;
 	    }
 	}
