@@ -573,7 +573,7 @@ DestroyScale(
  *
  * ConfigureScale --
  *
- *	This procedure is called to process an argv/argc list, plus the Tk
+ *	This procedure is called to process an objv/objc list, plus the Tk
  *	option database, in order to configure (or reconfigure) a scale
  *	widget.
  *
