@@ -3,9 +3,7 @@
 #	Color selection dialog for platforms that do not support a
 #	standard color selection dialog.
 #
-# RCS: @(#) $Id: clrpick.tcl,v 1.22.4.1 2010/01/20 23:43:51 patthoyts Exp $
-#
-# Copyright (c) 1996 Sun Microsystems, Inc.
+# Copyright © 1996 Sun Microsystems, Inc.
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -14,7 +12,7 @@
 #
 #	(1): Find out how many free colors are left in the colormap and
 #	     don't allocate too many colors.
-#	(2): Implement HSV color selection. 
+#	(2): Implement HSV color selection.
 #
 
 # Make sure namespaces exist
@@ -52,17 +50,19 @@ proc ::tk::dialog::color:: {args} {
     set data(NUM_COLORBARS) 16
 
     # BARS_WIDTH is the number of pixels wide the color bar portion of the
-    # canvas is. This number must be a multiple of NUM_COLORBARS
-    set data(BARS_WIDTH) 160
+    # canvas is. BARS_WIDTH, BARS_WIDTH * 1.25, BARS_WIDTH * 1.5, and
+    # BARS_WIDTH * 1.75 must be multiples of NUM_COLORBARS.
+    set data(BARS_WIDTH) [::tk::ScaleNum 192]
 
     # PLGN_WIDTH is the number of pixels wide of the triangular selection
-    # polygon. This also results in the definition of the padding on the 
-    # left and right sides which is half of PLGN_WIDTH. Make this number even.
-    set data(PLGN_HEIGHT) 10
+    # polygon. This also results in the definition of the padding on the
+    # left and right sides which is half of PLGN_WIDTH. PLGN_WIDTH,
+    # PLGN_WIDTH * 1.25, PLGN_WIDTH * 1.5, and PLGN_WIDTH * 1.75 must be even.
+    set data(PLGN_WIDTH) [::tk::ScaleNum 8]
 
-    # PLGN_HEIGHT is the height of the selection polygon and the height of the 
+    # PLGN_HEIGHT is the height of the selection polygon and the height of the
     # selection rectangle at the bottom of the color bar. No restrictions.
-    set data(PLGN_WIDTH) 10
+    set data(PLGN_HEIGHT) [::tk::ScaleNum 8]
 
     Config $dataName $args
     InitValues $dataName
@@ -91,7 +91,7 @@ proc ::tk::dialog::color:: {args} {
 
     # 5. Withdraw the window, then update all the geometry information
     # so we know how big it wants to be, then center the window in the
-    # display and de-iconify it.
+    # display (Motif style) and de-iconify it.
 
     ::tk::PlaceWindow $w widget $data(-parent)
     wm title $w $data(-title)
@@ -192,11 +192,13 @@ proc ::tk::dialog::color::Config {dataName argList} {
 	set data(-title) " "
     }
     if {[catch {winfo rgb . $data(-initialcolor)} err]} {
-	error $err
+	return -code error -errorcode [list TK LOOKUP COLOR $data(-initialcolor)] \
+	    $err
     }
 
     if {![winfo exists $data(-parent)]} {
-	error "bad window path name \"$data(-parent)\""
+	return -code error -errorcode [list TK LOOKUP WINDOW $data(-parent)] \
+	    "bad window path name \"$data(-parent)\""
     }
 }
 
@@ -235,7 +237,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
 	entry $box.entry -textvariable \
 		::tk::dialog::color::[winfo name $w]($color,intensity) \
 		-width 4
-	pack $box.label -side left -fill y -padx 2 -pady 3
+	pack $box.label -side left -fill y -padx 1.5p -pady 2p
 	pack $box.entry -side left -anchor n -pady 0
 	pack $box -side left -fill both
 
@@ -251,7 +253,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
 	pack $f.color -expand yes -fill both
 	pack $f.sel -expand yes -fill both
 
-	pack $f -side top -fill x -padx 0 -pady 2
+	pack $f -side top -fill x -padx 0 -pady 1.5p
 
 	set data($color,entry) $box.entry
 	set data($color,col) $f.color
@@ -272,7 +274,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
 	bind $box.entry <Return> [list tk::dialog::color::HandleRGBEntry $w]
     }
 
-    pack $stripsFrame -side left -fill both -padx 4 -pady 10
+    pack $stripsFrame -side left -fill both -padx 3p -pady 7.5p
 
     # The selFrame contains a frame that demonstrates the currently
     # selected color
@@ -284,10 +286,10 @@ proc ::tk::dialog::color::BuildDialog {w} {
 	    -textvariable ::tk::dialog::color::[winfo name $w](selection) \
 	    -width 16]
     set f1  [frame $selFrame.f1 -relief sunken -bd 2]
-    set data(finalCanvas) [frame $f1.demo -bd 0 -width 100 -height 70]
+    set data(finalCanvas) [frame $f1.demo -bd 0 -width 75p -height 51p]
 
-    pack $lab $ent -side top -fill x -padx 4 -pady 2
-    pack $f1 -expand yes -anchor nw -fill both -padx 6 -pady 10
+    pack $lab $ent -side top -fill x -padx 3p -pady 1.5p
+    pack $f1 -expand yes -anchor nw -fill both -padx 4.5p -pady 7.5p
     pack $data(finalCanvas) -expand yes -fill both
 
     bind $ent <Return> [list tk::dialog::color::HandleSelEntry $w]
@@ -308,7 +310,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
     set data(cancelBtn)  $botFrame.cancel
 
     grid x $botFrame.ok x $botFrame.cancel x -sticky ew
-    grid configure $botFrame.ok $botFrame.cancel -padx 10 -pady 10
+    grid configure $botFrame.ok $botFrame.cancel -padx 7.5p -pady 7.5p
     grid columnconfigure $botFrame {0 4} -weight 1 -uniform space
     grid columnconfigure $botFrame {1 3} -weight 1 -uniform button
     grid columnconfigure $botFrame 2 -weight 2 -uniform space
@@ -316,11 +318,10 @@ proc ::tk::dialog::color::BuildDialog {w} {
 
     # Accelerator bindings
     bind $lab <<AltUnderlined>> [list focus $ent]
-    bind $w <KeyPress-Escape> [list tk::ButtonInvoke $data(cancelBtn)]
+    bind $w <Escape> [list tk::ButtonInvoke $data(cancelBtn)]
     bind $w <Alt-Key> [list tk::AltKeyInDialog $w %A]
 
     wm protocol $w WM_DELETE_WINDOW [list tk::dialog::color::CancelCmd $w]
-    bind $lab <Destroy> [list tk::dialog::color::CancelCmd $w]
 }
 
 # ::tk::dialog::color::SetRGBValue --
@@ -328,7 +329,7 @@ proc ::tk::dialog::color::BuildDialog {w} {
 #	Sets the current selection of the dialog box
 #
 proc ::tk::dialog::color::SetRGBValue {w color} {
-    upvar ::tk::dialog::color::[winfo name $w] data 
+    upvar ::tk::dialog::color::[winfo name $w] data
 
     set data(red,intensity)   [lindex $color 0]
     set data(green,intensity) [lindex $color 1]
@@ -368,7 +369,7 @@ proc ::tk::dialog::color::RgbToX {w color} {
 }
 
 # ::tk::dialog::color::DrawColorScale --
-# 
+#
 #	Draw color scale is called whenever the size of one of the color
 #	scale canvases is changed.
 #
@@ -396,7 +397,7 @@ proc ::tk::dialog::color::DrawColorScale {w c {create 0}} {
 
 	# Draw the selection polygons
 	CreateSelector $w $sel $c
-	$sel bind $data($c,index) <ButtonPress-1> \
+	$sel bind $data($c,index) <Button-1> \
 		[list tk::dialog::color::StartMove $w $sel $c %x $data(selPad) 1]
 	$sel bind $data($c,index) <B1-Motion> \
 		[list tk::dialog::color::MoveSelector $w $sel $c %x $data(selPad)]
@@ -409,14 +410,14 @@ proc ::tk::dialog::color::DrawColorScale {w c {create 0}} {
 	set data($c,clickRegion) [$sel create rectangle 0 0 \
 		$data(canvasWidth) $height -fill {} -outline {}]
 
-	bind $col <ButtonPress-1> \
+	bind $col <Button-1> \
 		[list tk::dialog::color::StartMove $w $sel $c %x $data(colorPad)]
 	bind $col <B1-Motion> \
 		[list tk::dialog::color::MoveSelector $w $sel $c %x $data(colorPad)]
 	bind $col <ButtonRelease-1> \
 		[list tk::dialog::color::ReleaseMouse $w $sel $c %x $data(colorPad)]
 
-	$sel bind $data($c,clickRegion) <ButtonPress-1> \
+	$sel bind $data($c,clickRegion) <Button-1> \
 		[list tk::dialog::color::StartMove $w $sel $c %x $data(selPad)]
 	$sel bind $data($c,clickRegion) <B1-Motion> \
 		[list tk::dialog::color::MoveSelector $w $sel $c %x $data(selPad)]
@@ -507,7 +508,7 @@ proc ::tk::dialog::color::RedrawColorBars {w colorChanged} {
     upvar ::tk::dialog::color::[winfo name $w] data
 
     switch $colorChanged {
-	red { 
+	red {
 	    DrawColorScale $w green
 	    DrawColorScale $w blue
 	}
@@ -537,7 +538,7 @@ proc ::tk::dialog::color::RedrawColorBars {w colorChanged} {
 #	Handles a mousedown button event over the selector polygon.
 #	Adds the bindings for moving the mouse while the button is
 #	pressed.  Sets the binding for the button-release event.
-# 
+#
 # Params: sel is the selector canvas window, color is the color of the strip.
 #
 proc ::tk::dialog::color::StartMove {w sel color x delta {dontMove 0}} {
@@ -549,7 +550,7 @@ proc ::tk::dialog::color::StartMove {w sel color x delta {dontMove 0}} {
 }
 
 # ::tk::dialog::color::MoveSelector --
-# 
+#
 # Moves the polygon selector so that its middle point has the same
 # x value as the specified x. If x is outside the bounds [0,255],
 # the selector is set to the closest endpoint.
@@ -583,7 +584,7 @@ proc ::tk::dialog::color::MoveSelector {w sel color x delta} {
 #         x is the x-coord of the mouse.
 #
 proc ::tk::dialog::color::ReleaseMouse {w sel color x delta} {
-    upvar ::tk::dialog::color::[winfo name $w] data 
+    upvar ::tk::dialog::color::[winfo name $w] data
 
     set x [MoveSelector $w $sel $color $x $delta]
 
@@ -602,7 +603,7 @@ proc ::tk::dialog::color::ResizeColorBars {w} {
     upvar ::tk::dialog::color::[winfo name $w] data
 
     if {
-	($data(BARS_WIDTH) < $data(NUM_COLORBARS)) || 
+	($data(BARS_WIDTH) < $data(NUM_COLORBARS)) ||
 	(($data(BARS_WIDTH) % $data(NUM_COLORBARS)) != 0)
     } then {
 	set data(BARS_WIDTH) $data(NUM_COLORBARS)
@@ -660,7 +661,7 @@ proc ::tk::dialog::color::HandleRGBEntry {w} {
 
     SetRGBValue $w "$data(red,intensity) \
 	$data(green,intensity) $data(blue,intensity)"
-}    
+}
 
 # mouse cursor enters a color bar
 #
