@@ -7,7 +7,7 @@ if {![info exists widgetDemo]} {
     error "This script should be run from the \"widget\" demo."
 }
 
-package require Tk
+package require tk
 
 set w .paned2
 catch {destroy $w}
@@ -25,7 +25,7 @@ pack $btns -side bottom -fill x
 
 # Create the pane itself
 panedwindow $w.pane -orient vertical
-pack $w.pane -side top -expand yes -fill both -pady 2 -padx 2m
+pack $w.pane -side top -expand yes -fill both -pady 1.5p -padx 2m
 
 # The top window is a listbox with scrollbar
 set paneList {
@@ -54,7 +54,7 @@ listbox $f.list -listvariable paneList -yscrollcommand "$f.scr set"
 # Invert the first item to highlight it
 $f.list itemconfigure 0 \
 	-background [$f.list cget -fg] -foreground [$f.list cget -bg]
-scrollbar $f.scr -orient vertical -command "$f.list yview"
+ttk::scrollbar $f.scr -orient vertical -command "$f.list yview"
 pack $f.scr -side right -fill y
 pack $f.list -fill both -expand 1
 
@@ -62,8 +62,8 @@ pack $f.list -fill both -expand 1
 set f [frame $w.pane.bottom]
 text $f.text -xscrollcommand "$f.xscr set" -yscrollcommand "$f.yscr set" \
 	-width 30 -height 8 -wrap none
-scrollbar $f.xscr -orient horizontal -command "$f.text xview"
-scrollbar $f.yscr -orient vertical -command "$f.text yview"
+ttk::scrollbar $f.xscr -orient horizontal -command "$f.text xview"
+ttk::scrollbar $f.yscr -orient vertical -command "$f.text yview"
 grid $f.text $f.yscr -sticky nsew
 grid $f.xscr         -sticky nsew
 grid columnconfigure $f 0 -weight 1
@@ -71,4 +71,4 @@ grid rowconfigure    $f 0 -weight 1
 $f.text insert 1.0 "This is just a normal text widget"
 
 # Now add our contents to the paned window
-$w.pane add $w.pane.top $w.pane.bottom
+$w.pane add $w.pane.top $w.pane.bottom -stretch always
