@@ -408,7 +408,7 @@ proc ::tk::MenuUnpost menu {
 #
 # Arguments:
 # w -			The name of the menubutton widget.
-# upDown - 		"down" means button 1 is pressed, "up" means
+# upDown -		"down" means button 1 is pressed, "up" means
 #			it isn't.
 # rootx, rooty -	Coordinates of mouse, in (virtual?) root window.
 
@@ -891,7 +891,7 @@ proc ::tk::MenuNextEntry {menu count} {
 
 proc ::tk::MenuFind {w char} {
     set char [string tolower $char]
-    set windowlist [winfo child $w]
+    set windowlist [winfo children $w]
 
     foreach child $windowlist {
 	# Don't descend into other toplevels.
@@ -925,8 +925,12 @@ proc ::tk::MenuFind {w char} {
 	}
 	switch -- [winfo class $child] {
 	    Menubutton {
-		set char2 [string index [$child cget -text] \
-			[$child cget -underline]]
+		if {[$child cget -underline] < 0} {
+		    set char2 ""
+		} else {
+		    set char2 [string index [$child cget -text] \
+			    [$child cget -underline]]
+		}
 		if {$char eq [string tolower $char2] || $char eq ""} {
 		    if {[$child cget -state] ne "disabled"} {
 			return $child
@@ -1199,18 +1203,18 @@ if {[tk windowingsystem] eq "aqua"} {
 		incr x [expr {[winfo width $button]}]
 	    }
 	    default {  # flush
-                if {[$button cget -indicatoron]} {
-                    if {$cx ne ""} {
-                        set x [expr {$cx - [winfo reqwidth $menu] / 2}]
-                        set l [font metrics [$menu cget -font] -linespace]
-                        set y [expr {$cy - $l/2 - 2}]
-                    } else {
-                        incr x [expr {([winfo width $button] - \
+		if {[$button cget -indicatoron]} {
+		    if {$cx ne ""} {
+			set x [expr {$cx - [winfo reqwidth $menu] / 2}]
+			set l [font metrics [$menu cget -font] -linespace]
+			set y [expr {$cy - $l/2 - 2}]
+		    } else {
+			incr x [expr {([winfo width $button] - \
 				[winfo reqwidth $menu])/ 2}]
-                    }
-                } else {
-                    incr y [winfo height $button]
-                }
+		    }
+		} else {
+		    incr y [winfo height $button]
+		}
 	    }
 	}
 	PostOverPoint $menu $x $y $entry
