@@ -52,17 +52,6 @@ typedef union MacPixel_t {
     xpixel pixel;
 } MacPixel;
 
-/*
- * We maintain two colormaps, one for the LightAqua appearance and one for the
- * DarkAqua appearance.
- */
-
-enum macColormap {
-    noColormap,
-    lightColormap,
-    darkColormap,
-};
-
 /*
  * In TkMacOSXColor.c a Tk hash table is constructed from the static data
  * below to map system color names to CGColors.
@@ -87,10 +76,10 @@ typedef struct {
 
 static SystemColorDatum systemColorData[] = {
 {"Pixel",				rgbColor, 0, NULL, 0, NULL },
-{"Transparent",			       	clearColor,   0, NULL, 0, NULL },
+{"Transparent",					clearColor,   0, NULL, 0, NULL },
 
 {"Highlight",				HIBrush,  kThemeBrushPrimaryHighlightColor, NULL, 0, NULL },
-{"HighlightSecondary",		    	HIBrush,  kThemeBrushSecondaryHighlightColor, NULL, 0, NULL },
+{"HighlightSecondary",			HIBrush,  kThemeBrushSecondaryHighlightColor, NULL, 0, NULL },
 {"HighlightText",			HIBrush,  kThemeBrushBlack, NULL, 0, NULL },
 {"HighlightAlternate",			HIBrush,  kThemeBrushAlternatePrimaryHighlightColor, NULL, 0, NULL },
 {"PrimaryHighlightColor",		HIBrush,  kThemeBrushPrimaryHighlightColor, NULL, 0, NULL },
