@@ -367,7 +367,7 @@ TkCursor *
 TkGetCursorByName(
     Tcl_Interp *interp,		/* Interpreter to use for error reporting. */
     TCL_UNUSED(Tk_Window),		/* Window in which cursor will be used. */
-    Tk_Uid string)		/* Description of cursor. See manual entry
+    const char *string)		/* Description of cursor. See manual entry
 				 * for details on legal syntax. */
 {
     TkMacOSXCursor *macCursorPtr = NULL;
@@ -393,7 +393,7 @@ TkGetCursorByName(
 	    macCursorPtr->type != NONE)) {
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		"bad cursor spec \"%s\"", string));
-	Tcl_SetErrorCode(interp, "TK", "VALUE", "CURSOR", NULL);
+	Tcl_SetErrorCode(interp, "TK", "VALUE", "CURSOR", (char *)NULL);
 	if (macCursorPtr) {
 	    ckfree(macCursorPtr);
 	    macCursorPtr = NULL;
