@@ -689,7 +689,7 @@ CreateCGImageFromDrawableRect(
 		    //CGImageGetBytesPerRow(cg_image), // wastes space?
 		    CGImageGetBitsPerPixel(cg_image) * width / 8,
 		    colorspace,
-		    CGImageGetAlphaInfo(cg_image));
+		    CGImageGetBitmapInfo(cg_image));
 	    CGColorSpaceRelease(colorspace);
 	    if (cg_context) {
 		// Extract the subimage in the specified rectangle.
@@ -1211,9 +1211,13 @@ XCopyPlane(
 		    CGImageRelease(submask);
 		    CGImageRelease(subimage);
 		} else {
+		    srcRect = CGRectMake(src_x, src_y, width, height);
+		    CGImageRef subimage = CGImageCreateWithImageInRect(
+			    img, srcRect);
 		    dstRect = CGRectMake(dest_x, dest_y, width, height);
-		    TkMacOSXDrawCGImage(dst, gc, dc.context, img,
+		    TkMacOSXDrawCGImage(dst, gc, dc.context, subimage,
 			    gc->foreground, imageBackground, dstRect);
+		    CGImageRelease(subimage);
 		    CGImageRelease(img);
 		}
 	    } else {
@@ -1472,7 +1476,7 @@ TkMacOSXNSImageConfigureModel(
 
     if (modelPtr->sourceObj == NULL) {
 	Tcl_SetObjResult(interp, Tcl_NewStringObj("-source is required.", TCL_INDEX_NONE));
-	Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", NULL);
+	Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", (char *)NULL);
 	goto errorExit;
     }
 
@@ -1483,7 +1487,7 @@ TkMacOSXNSImageConfigureModel(
 	Tcl_SetObjResult(interp, Tcl_NewStringObj(
 	    "Unknown interpretation for source in -as option.  "
 	    "Should be name, file, path, or filetype.", TCL_INDEX_NONE));
-	Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", NULL);
+	Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", (char *)NULL);
 	goto errorExit;
     }
 
@@ -1544,18 +1548,18 @@ TkMacOSXNSImageConfigureModel(
 	    Tcl_SetObjResult(interp, Tcl_NewStringObj("Unknown named NSImage.\n"
 		"Try omitting ImageName, "
 		"e.g. use NSCaution for NSImageNameCaution.", TCL_INDEX_NONE));
-	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", (char *)NULL);
 	    goto errorExit;
 	case FILE_SOURCE:
 	    Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		"Failed to load image file.\n", TCL_INDEX_NONE));
-	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", (char *)NULL);
 	    goto errorExit;
 	default:
 	    Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		"Unrecognized file type.\n"
 		"If using a filename extension, do not include the dot.\n", TCL_INDEX_NONE));
-	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "IMAGE", "SYSTEM", "BAD_VALUE", (char *)NULL);
 	    goto errorExit;
 	}
     }
