@@ -190,6 +190,7 @@ XMapWindow(
 	    if (initialized) {
 		if ([win canBecomeKeyWindow]) {
 		    [win makeKeyAndOrderFront:NSApp];
+		    [NSApp setTkEventTarget:TkMacOSXGetTkWindow(win)];
 		} else {
 		    [win orderFrontRegardless];
 		}
@@ -360,6 +361,7 @@ XUnmapWindow(
 				  wmInfoPtr->hints.initial_state != WithdrawnState);
 		    if (w != win && isOnScreen && [w canBecomeKeyWindow]) {
 			[w makeKeyAndOrderFront:NSApp];
+			[NSApp setTkEventTarget:TkMacOSXGetTkWindow(win)];
 			break;
 		    }
 		}
@@ -1018,7 +1020,6 @@ TkMacOSXRedrawViewIdleTask(
     TKContentView *view = (TKContentView *) clientData;
     //    fprintf(stderr, "idle redraw for %p\n", view);
     [view generateExposeEvents:[view bounds]];
-    [view setNeedsDisplay:YES];
 }
 
 void
@@ -1039,7 +1040,6 @@ TkMacOSXInvalidateWindow(
 	TkMacOSXInvalClipRgns(parent);
     }
     [view generateExposeEvents:[view bounds]];
-    [view setNeedsDisplay:YES];
 }
 
 /*
