@@ -205,7 +205,7 @@ TkCursor *
 TkGetCursorByName(
     Tcl_Interp *interp,		/* Interpreter to use for error reporting. */
     Tk_Window tkwin,		/* Window in which cursor will be used. */
-    Tk_Uid string)		/* Description of cursor. See manual entry for
+    const char *string)		/* Description of cursor. See manual entry for
 				 * details on legal syntax. */
 {
     TkUnixCursor *cursorPtr = NULL;
@@ -277,7 +277,7 @@ TkGetCursorByName(
 	    if (TkParseColor(display, Tk_Colormap(tkwin), argv[1], &fg) == 0) {
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			"invalid color name \"%s\"", argv[1]));
-		Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", NULL);
+		Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", (char *)NULL);
 		goto cleanup;
 	    }
 	    if (argc == 2) {
@@ -287,7 +287,7 @@ TkGetCursorByName(
 		    &bg) == 0) {
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 			"invalid color name \"%s\"", argv[2]));
-		Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", NULL);
+		Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", (char *)NULL);
 		goto cleanup;
 	    }
 	}
@@ -297,7 +297,7 @@ TkGetCursorByName(
 	    if (dispPtr->cursorFont == None) {
 		Tcl_SetObjResult(interp, Tcl_NewStringObj(
 			"couldn't load cursor font", TCL_INDEX_NONE));
-		Tcl_SetErrorCode(interp, "TK", "CURSOR", "FONT", NULL);
+		Tcl_SetErrorCode(interp, "TK", "CURSOR", "FONT", (char *)NULL);
 		goto cleanup;
 	    }
 	}
@@ -313,7 +313,7 @@ TkGetCursorByName(
 	    Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		    "cannot get cursor from a file in a safe interpreter",
 		    TCL_INDEX_NONE));
-	    Tcl_SetErrorCode(interp, "TK", "SAFE", "CURSOR_FILE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "SAFE", "CURSOR_FILE", (char *)NULL);
 	    cursorPtr = NULL;
 	    goto cleanup;
 	}
@@ -354,7 +354,7 @@ TkGetCursorByName(
 	ckfree(argv);
     }
     Tcl_SetObjResult(interp, Tcl_ObjPrintf("bad cursor spec \"%s\"", string));
-    Tcl_SetErrorCode(interp, "TK", "VALUE", "CURSOR", NULL);
+    Tcl_SetErrorCode(interp, "TK", "VALUE", "CURSOR", (char *)NULL);
     return NULL;
 }
 
@@ -428,7 +428,7 @@ CreateCursorFromTableOrFile(
 	if (data == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "error reading bitmap data for \"%s\"", argv[0]));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "BITMAP_DATA", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "BITMAP_DATA", (char *)NULL);
 	    goto cleanup;
 	}
 
@@ -440,7 +440,7 @@ CreateCursorFromTableOrFile(
 		&source, &xHot, &yHot) != BitmapSuccess) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "cleanup reading bitmap file \"%s\"", &argv[0][1]));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "BITMAP_FILE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "BITMAP_FILE", (char *)NULL);
 	    goto cleanup;
 	}
     }
@@ -453,7 +453,7 @@ CreateCursorFromTableOrFile(
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "bad hot spot in bitmap file \"%s\"", &argv[0][1]));
 	}
-	Tcl_SetErrorCode(interp, "TK", "CURSOR", "HOTSPOT", NULL);
+	Tcl_SetErrorCode(interp, "TK", "CURSOR", "HOTSPOT", (char *)NULL);
 	goto cleanup;
     }
 
@@ -469,7 +469,7 @@ CreateCursorFromTableOrFile(
 	if (TkParseColor(display, Tk_Colormap(tkwin), fgColor, &fg) == 0) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "invalid color name \"%s\"", fgColor));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", (char *)NULL);
 	    goto cleanup;
 	}
 	if (inTkTable) {
@@ -489,13 +489,13 @@ CreateCursorFromTableOrFile(
 	if (TkParseColor(display, Tk_Colormap(tkwin), fgColor, &fg) == 0) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "invalid color name \"%s\"", fgColor));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", (char *)NULL);
 	    goto cleanup;
 	}
 	if (TkParseColor(display, Tk_Colormap(tkwin), bgColor, &bg) == 0) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "invalid color name \"%s\"", bgColor));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "COLOR", (char *)NULL);
 	    goto cleanup;
 	}
     }
@@ -526,7 +526,7 @@ CreateCursorFromTableOrFile(
 	if (data == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "error reading bitmap mask data for \"%s\"", argv[0]));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "MASK_DATA", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "MASK_DATA", (char *)NULL);
 	    goto cleanup;
 	}
 
@@ -540,7 +540,7 @@ CreateCursorFromTableOrFile(
 		&mask, &dummy1, &dummy2) != BitmapSuccess) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "cleanup reading bitmap file \"%s\"", argv[1]));
-	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "MASK_FILE", NULL);
+	    Tcl_SetErrorCode(interp, "TK", "CURSOR", "MASK_FILE", (char *)NULL);
 	    goto cleanup;
 	}
     }
@@ -548,7 +548,7 @@ CreateCursorFromTableOrFile(
     if ((maskWidth != width) || (maskHeight != height)) {
 	Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		"source and mask bitmaps have different sizes", TCL_INDEX_NONE));
-	Tcl_SetErrorCode(interp, "TK", "CURSOR", "SIZE_MATCH", NULL);
+	Tcl_SetErrorCode(interp, "TK", "CURSOR", "SIZE_MATCH", (char *)NULL);
 	goto cleanup;
     }
 
