@@ -62,7 +62,7 @@ TkSelGetSelection(
     if (!OpenClipboard(NULL)) {
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		"clipboard cannot be opened, another application grabbed it"));
-	Tcl_SetErrorCode(interp, "TK", "CLIPBOARD", "BUSY", NULL);
+	Tcl_SetErrorCode(interp, "TK", "CLIPBOARD", "BUSY", (char *)NULL);
 	return TCL_ERROR;
     }
 
@@ -204,7 +204,7 @@ TkSelGetSelection(
     Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 	    "%s selection doesn't exist or form \"%s\" not defined",
 	    Tk_GetAtomName(tkwin, selection), Tk_GetAtomName(tkwin, target)));
-    Tcl_SetErrorCode(interp, "TK", "SELECTION", "EXISTS", NULL);
+    Tcl_SetErrorCode(interp, "TK", "SELECTION", "EXISTS", (char *)NULL);
     return TCL_ERROR;
 }
 
