@@ -53,11 +53,6 @@ SOFTWARE.
 #define X_PROTOCOL	11		/* current protocol version */
 #define X_PROTOCOL_REVISION 0		/* current minor version */
 
-#if defined(MAC_OSX_TK)
-#   define Cursor XCursor
-#   define Region XRegion
-#endif
-
 /* Resources */
 
 /*
@@ -69,11 +64,7 @@ SOFTWARE.
 #  ifndef _XTYPEDEF_XID
 #    define _XTYPEDEF_XID
 #    ifdef _WIN64
-#      ifdef _MSC_VER
-typedef unsigned __int64 XID;
-#      else
 typedef unsigned long long XID;
-#      endif
 #    else
 typedef unsigned long XID;
 #    endif
@@ -118,7 +109,7 @@ typedef XID Colormap;
 typedef XID GContext;
 typedef XID KeySym;
 
-typedef unsigned long KeyCode;	/* In order to use IME, the Macintosh needs
+typedef unsigned int KeyCode;	/* In order to use IME, the Macintosh needs
 				 * to pack 3 bytes into the keyCode field in
 				 * the XEvent.  In the real X.h, a KeyCode is
 				 * defined as an unsigned char, which wouldn't
@@ -128,11 +119,9 @@ typedef unsigned long KeyCode;	/* In order to use IME, the Macintosh needs
  * RESERVED RESOURCE AND CONSTANT DEFINITIONS
  *****************************************************************/
 
-#ifndef _WIN32
-#   define None              0L      /* See bug [9e31fd9449] and below */
-#else
+#ifndef None
 /* Perl-Tk expects None to be a macro. See ticket [593eb0227c] */
-#   define None              None    /* uses the enum below */
+#define None                 None /* See bug [9e31fd9449] and below */
 #endif
 
 #define ParentRelative       1L	/* background pixmap in CreateWindow
@@ -231,7 +220,8 @@ are reserved in the protocol for errors and replies. */
 #define ColormapNotify		32
 #define ClientMessage		33
 #define MappingNotify		34
-#define LASTEvent		35	/* must be bigger than any event # */
+#define GenericEvent		35
+#define LASTEvent		36	/* must be bigger than any event # */
 
 
 /* Key masks. Used as modifiers to GrabButton and GrabKey, results of QueryPointer,
@@ -239,12 +229,8 @@ are reserved in the protocol for errors and replies. */
 
 #define ShiftMask		(1<<0)
 #define LockMask		(1<<1)
-#ifndef _WIN32
-#   define ControlMask		(1<<2) /* See bug [9e31fd9449] and below */
-#else
 /* Perl-Tk expects ControlMask to be a macro. See ticket [593eb0227c] */
-#   define ControlMask		ControlMask /* uses the enum below */
-#endif
+#define ControlMask		ControlMask /* See bug [9e31fd9449] and below */
 #define Mod1Mask		(1<<3)
 #define Mod2Mask		(1<<4)
 #define Mod3Mask		(1<<5)
@@ -252,9 +238,7 @@ are reserved in the protocol for errors and replies. */
 #define Mod5Mask		(1<<7)
 
 /* See bug [9e31fd9449], this way prevents conflicts with Win32 headers */
-#ifdef _WIN32
 enum { None = 0, ControlMask = (1<<2) };
-#endif
 
 /* modifier names.  Used to build a SetModifierMapping request or
    to read a GetModifierMapping request.  These correspond to the
@@ -743,9 +727,4 @@ enum { None = 0, ControlMask = (1<<2) };
 #define LSBFirst		0
 #define MSBFirst		1
 
-#if defined(MAC_OSX_TK)
-#   undef Cursor
-#   undef Region
-#endif
-
 #endif /* X_H */
